============================================================
scTSS: Detection and couting alternative TSS in single cells
============================================================

Installation
============

You can install from this GitHub repository for latest (often development) 
version by following command line

.. code-block:: bash

  pip install -U git+https://github.com/StatBiomed/scTSS

In either case, add ``--user`` if you don't have the write permission for your 
Python environment.


Quick start
===========

Coming soon...